@@ -44,12 +44,10 @@ extern void simple_loci_derivatives (double *d, nr_fmt * nr,
 				     timearchive_fmt ** tyme, long locus);
 extern void copy_and_clear_d (nr_fmt * nr);
 extern void add_back_d (nr_fmt * nr);
-extern void setup_parameter0 (world_fmt * world, nr_fmt * nr, long repkind,
+extern void setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind,
 			      long repstart, long repstop, long loci,
 			      long kind, boolean multilocus);
 
-extern double (*calc_like) (nr_fmt *, double *, double *, long);
-
 extern void combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv);
 
 extern long maximize (double *param, world_fmt * world, nr_fmt * nr,
