@@ -23,8 +23,6 @@ $Id: data.c,v 1.37 2001/09/07 23:56:13 beerli Exp $
 
 #include "migration.h"
 
-extern long number_genomes (char type);
-
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
@@ -1022,7 +1020,7 @@ read_geofile (data_fmt * data, option_fmt * options, long numpop)
 	      1./data->ogeo[i][j];
 	    data->lgeo[mm2m (i, j, numpop)] =
 	      data->lgeo[mm2m (j, i, numpop)] =
-	      data->ogeo[i][j] > 0.0 ? log (1./data->ogeo[i][j]) : -DBL_MAX;;
+	      data->ogeo[i][j] > 0.0 ? log (1./data->ogeo[i][j]) : -DBL_MAX;
 	  }
     }
 }
