@@ -404,19 +404,20 @@ else
 #endif
       get_data (data->infile, data, options);
 #ifdef MPI
-      //broadcast_data_master(data,options);
+      broadcast_data_master(data,options);
       if (numcpu == 1)
 	{
 	  error
-	    ("This program was compiled to use a parallel computer\n and you tried to run it on only a single node.\nThis will not work because it uses a \n\"single_master-many_worker\" architecture \nand needs at least TWO nodes and TWO loci\n");
+	    ("This program was compiled to use a parallel computer\n and you tried to run it on only a single node.\nThis will not work because it uses a \n\"single_master-many_worker\" architecture \nand needs at least TWO nodes\n");
 	}
     }
   else
     {
-      get_data (data->infile, data, options);
+      //get_data (data->infile, data, options);
+	broadcast_data_worker(data,options);  
     }		
      MPI_Comm_dup(comm_world, &comm_all_worlds);
-	MPI_Comm_rank(comm_world, &myID);
+     MPI_Comm_rank(comm_world, &myID);
 #endif
   set_plot (options);
   init_world (EARTH, data, options);
