@@ -13,7 +13,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: mcmc1.c,v 1.55 2001/07/25 19:27:24 beerli Exp $
+$Id: mcmc1.c,v 1.56 2001/09/07 23:56:13 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "random.h"
@@ -1109,7 +1109,7 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
 		    proposal->world->root->next->back,
 		    proposal->world->data->uepsites);
       proposal->firstuep =
-	first_uep (first, NULL, proposal->world->data->uepsites);
+	first_uep (first, proposal->world->root, proposal->world->data->uepsites);
       proposal->ueplikelihood = pseudo_ueplikelihood (world, proposal);
       proposal->likelihood = pseudotreelikelihood (world, proposal);
       //      printf("%s> pl=%f pul=%f\n",proposal->world->name,proposal->likelihood,proposal->ueplikelihood);
