@@ -13,7 +13,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: mcmc2.c,v 1.16 2001/06/02 21:40:21 beerli Exp $
+$Id: mcmc2.c,v 1.17 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -66,7 +66,8 @@ void adjust (node * theNode, double tyme, long level);
 void localevaluate (node * mother);
 void copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2);
 void fix_root_pop (node * p);
-void pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx, node * mother, node * newdaughter, double v);
+void pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx,
+		     node * mother, node * newdaughter, double v);
 node *crawl_down (node * theNode, double tyme);
 
 
@@ -82,12 +83,15 @@ coalesce1p (proposal_fmt * proposal)
   if (proposal->target == proposal->ocousin)
     {
       coat_ocousin (proposal);
-      if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme && crawlback (proposal->oback)->type != 'r')
+      if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme
+	  && crawlback (proposal->oback)->type != 'r')
 	error ("problem with time encountered");	/* was >= ** */
     }
   else
     {
-      if (((proposal->target == proposal->oback) || (proposal->target == proposal->osister) || (proposal->target == proposal->origin)))
+      if (((proposal->target == proposal->oback)
+	   || (proposal->target == proposal->osister)
+	   || (proposal->target == proposal->origin)))
 	{
 	  obb = proposal->oback->back;
 	  coat_oback (proposal);
@@ -107,11 +111,13 @@ coalesce1p (proposal_fmt * proposal)
 	  if (crawlback (proposal->target)->type == 'r')
 	    {
 	      coat_rbcoa (proposal);
-	      if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)
+	      if (proposal->oback->tyme >
+		  showtop (proposal->oback->back)->tyme)
 		{		/* was >= ** */
 		  if (proposal->oback->back->type == 'r')
 		    {
-		      adjust (proposal->root, proposal->oback->tyme + 10000, 0);
+		      adjust (proposal->root, proposal->oback->tyme + 10000,
+			      0);
 		      comment ("Root time adjusted: was to small");
 		    }
 		  else
@@ -136,17 +142,24 @@ coalesce1p (proposal_fmt * proposal)
 	    }
 	}
     }
-  set_pop (proposal->oback, proposal->origin->actualpop, proposal->origin->actualpop);
+  set_pop (proposal->oback, proposal->origin->actualpop,
+	   proposal->origin->actualpop);
 /*   free_migr_node(proposal->origin, crawlback(proposal->origin)); */
   if (proposal->migr_table_counter > 0)
     {
-      set_pop (proposal->oback, proposal->migr_table[proposal->migr_table_counter - 1].from, proposal->migr_table[proposal->migr_table_counter - 1].from);
-      insert_migr_node (proposal->world, proposal->origin, crawlback (proposal->origin), proposal->migr_table, &(proposal->migr_table_counter));
+      set_pop (proposal->oback,
+	       proposal->migr_table[proposal->migr_table_counter - 1].from,
+	       proposal->migr_table[proposal->migr_table_counter - 1].from);
+      insert_migr_node (proposal->world, proposal->origin,
+			crawlback (proposal->origin), proposal->migr_table,
+			&(proposal->migr_table_counter));
     }
   proposal->migr_table_counter = 0;
   if (proposal->migr_table_counter2)
     {
-      insert_migr_node (proposal->world, proposal->realtarget, crawlback (proposal->target), proposal->migr_table2, &(proposal->migr_table_counter2));
+      insert_migr_node (proposal->world, proposal->realtarget,
+			crawlback (proposal->target), proposal->migr_table2,
+			&(proposal->migr_table_counter2));
       proposal->migr_table_counter2 = 0;
     }
   /*    if (proposal->oback == crawlback(proposal->root->next)) */
@@ -164,7 +177,9 @@ pretendcoalesce1p (proposal_fmt * proposal)
     }
   else
     {
-      if (((proposal->target == proposal->oback) || (proposal->target == proposal->osister) || (proposal->target == proposal->origin)))
+      if (((proposal->target == proposal->oback)
+	   || (proposal->target == proposal->osister)
+	   || (proposal->target == proposal->origin)))
 	{
 	  target_oback (proposal);
 	}
@@ -176,7 +191,9 @@ pretendcoalesce1p (proposal_fmt * proposal)
 	    }
 	  else
 	    {
-	      if ((showtop (crawlback (proposal->oback)) != NULL) && (showtop (crawlback (proposal->oback)) == proposal->target))
+	      if ((showtop (crawlback (proposal->oback)) != NULL)
+		  && (showtop (crawlback (proposal->oback)) ==
+		      proposal->target))
 		{
 		  target_obbcoa (proposal);
 		}
@@ -275,7 +292,8 @@ coat_obbcoa (proposal_fmt * proposal)
       adjust_time (proposal->oback, proposal->time);
       if (showtop (proposal->realtarget->back)->type == 'm')
 	{
-	  connectnodes (showtop (proposal->realtarget->back), proposal->oback, NULL);
+	  connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+			NULL);
 	}
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->tsister, proposal->oback);
@@ -303,7 +321,8 @@ coat_stancoa (proposal_fmt * proposal)
       connectnodes (obb, proposal->osister, proposal->ocousin);
       adjust_time (proposal->oback, proposal->time);
       if (showtop (proposal->realtarget->back)->type == 'm')
-	connectnodes (showtop (proposal->realtarget->back), proposal->oback, NULL);
+	connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+		      NULL);
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->oback, proposal->tsister);
       adjust (proposalack, proposalack->tyme, 3);
@@ -322,7 +341,8 @@ coat_stancoa (proposal_fmt * proposal)
       adjust_time (proposal->oback, proposal->time);
       proposal->oback->back = NULL;
       if (showtop (proposal->realtarget->back)->type == 'm')
-	connectnodes (showtop (proposal->realtarget->back), proposal->oback, NULL);
+	connectnodes (showtop (proposal->realtarget->back), proposal->oback,
+		      NULL);
       connectnodes (proposal->oback, proposal->origin, proposal->target);
       connectnodes (proposalack, proposal->oback, proposal->tsister);
       /* either proposalack is osister or a descendent of her
@@ -342,11 +362,14 @@ target_oback (proposal_fmt * proposal)
 {
   node *obb = showtop (crawlback (proposal->oback));
   copy_x (proposal, proposal->xf, proposal->origin->x);
-  memcpy(proposal->mf,proposal->origin->scale,sizeof(double)*proposal->endsite);
+  memcpy (proposal->mf, proposal->origin->scale,
+	  sizeof (double) * proposal->endsite);
   proposal->v = (proposal->time - proposal->origin->tyme);
   proposal->vs = (proposal->time - proposal->osister->tyme);
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->osister->x, proposal->osister->scale, proposal->vs);
-  pseudoevaluate (proposal, proposal->xf, proposal->mf, obb, proposal->oback, fabs (proposal->time - obb->tyme));
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		proposal->osister->x, proposal->osister->scale, proposal->vs);
+  pseudoevaluate (proposal, proposal->xf, proposal->mf, obb, proposal->oback,
+		  fabs (proposal->time - obb->tyme));
 }
 
 void
@@ -355,16 +378,22 @@ target_ocousin (proposal_fmt * proposal)
   node *obb;
   obb = showtop (crawlback (proposal->oback));
   copy_x (proposal, proposal->xf, proposal->origin->x);
-  memcpy(proposal->mf,proposal->origin->scale,sizeof(double)*proposal->endsite);
+  memcpy (proposal->mf, proposal->origin->scale,
+	  sizeof (double) * proposal->endsite);
   copy_x (proposal, proposal->xt, proposal->ocousin->x);
-  memcpy(proposal->mt,proposal->ocousin->scale,sizeof(double)*proposal->endsite);
+  memcpy (proposal->mt, proposal->ocousin->scale,
+	  sizeof (double) * proposal->endsite);
   proposal->v = (proposal->time - proposal->origin->tyme);
   proposal->vs = fabs (proposal->ocousin->tyme - proposal->time);
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->xt, proposal->mt, proposal->vs);
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		proposal->xt, proposal->mt, proposal->vs);
   proposal->v = fabs (proposal->time - obb->tyme);
   proposal->vs = obb->tyme - proposal->osister->tyme;
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->osister->x, proposal->osister->scale, proposal->vs);
-  pseudoevaluate (proposal, proposal->xf, proposal->mf, showtop (crawlback (obb)), obb, (showtop (crawlback (obb))->tyme - obb->tyme));
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		proposal->osister->x, proposal->osister->scale, proposal->vs);
+  pseudoevaluate (proposal, proposal->xf, proposal->mf,
+		  showtop (crawlback (obb)), obb,
+		  (showtop (crawlback (obb))->tyme - obb->tyme));
 }
 
 void
@@ -377,14 +406,21 @@ target_rbcoa (proposal_fmt * proposal)
       proposal->vs = obb->tyme - proposal->osister->tyme;
       proposal->v = obb->tyme - proposal->ocousin->tyme;
       copy_x (proposal, proposal->xt, proposal->osister->x);
-      memcpy(proposal->mt,proposal->osister->scale, sizeof(double)*proposal->endsite);
-      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
-      pseudoevaluate (proposal, proposal->xt, proposal->mt, showtop (crawlback (obb)), obb, showtop (crawlback (obb))->tyme - obb->tyme);
+      memcpy (proposal->mt, proposal->osister->scale,
+	      sizeof (double) * proposal->endsite);
+      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
+		    proposal->ocousin->x, proposal->ocousin->scale,
+		    proposal->v);
+      pseudoevaluate (proposal, proposal->xt, proposal->mt,
+		      showtop (crawlback (obb)), obb,
+		      showtop (crawlback (obb))->tyme - obb->tyme);
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = proposal->time - proposal->target->tyme;
       copy_x (proposal, proposal->xf, proposal->origin->x);
-      memcpy(proposal->mf,proposal->origin->scale, sizeof(double)*proposal->endsite);
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->xt, proposal->mt, proposal->vs);
+      memcpy (proposal->mf, proposal->origin->scale,
+	      sizeof (double) * proposal->endsite);
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		    proposal->xt, proposal->mt, proposal->vs);
     }
   else
     {
@@ -402,16 +438,22 @@ target_obbcoa (proposal_fmt * proposal)
       proposal->vs = obb->tyme - proposal->osister->tyme;
       proposal->v = obb->tyme - proposal->ocousin->tyme;
       copy_x (proposal, proposal->xt, proposal->osister->x);
-      memcpy(proposal->mt,proposal->osister->scale, sizeof(double)*proposal->endsite);
-      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
+      memcpy (proposal->mt, proposal->osister->scale,
+	      sizeof (double) * proposal->endsite);
+      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
+		    proposal->ocousin->x, proposal->ocousin->scale,
+		    proposal->v);
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = fabs (obb->tyme - proposal->time);
       copy_x (proposal, proposal->xf, proposal->origin->x);
-      memcpy(proposal->mf,proposal->origin->scale, sizeof(double)*proposal->endsite);
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->xt, proposal->mt, proposal->vs);
+      memcpy (proposal->mf, proposal->origin->scale,
+	      sizeof (double) * proposal->endsite);
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		    proposal->xt, proposal->mt, proposal->vs);
       proposal->v = fabs (showtop (crawlback (obb))->tyme - proposal->time);
       obbb = showtop (crawlback (obb));
-      pseudoevaluate (proposal, proposal->xf, proposal->mf, obbb, obb, proposal->v);
+      pseudoevaluate (proposal, proposal->xf, proposal->mf, obbb, obb,
+		      proposal->v);
     }
   else
     {
@@ -446,17 +488,20 @@ target_stancoa (proposal_fmt * proposal)
 	  else
 	    {
 	      gotoroot (obb, proposal->line_f);
-	      proposal->connect = findcrossing (proposal->line_f, proposal->line_t);
+	      proposal->connect =
+		findcrossing (proposal->line_f, proposal->line_t);
 	      proposal->vs = obb->tyme - proposal->osister->tyme;
 	      proposal->v = obb->tyme - proposal->ocousin->tyme;
 	      copy_x (proposal, proposal->xt, proposal->osister->x);
-	      memcpy(proposal->mt,proposal->osister->scale, sizeof(double)*proposal->endsite);
+	      memcpy (proposal->mt, proposal->osister->scale,
+		      sizeof (double) * proposal->endsite);
 	      /*       if (obb!=proposal->connect) { */
 	      upper = t_s_obbncon (proposal, obb);
 	      /*} */
 	      proposal->v = proposal->time - proposal->origin->tyme;
 	      copy_x (proposal, proposal->xf, proposal->origin->x);
-	      memcpy(proposal->mf,proposal->origin->scale, sizeof(double)*proposal->endsite);
+	      memcpy (proposal->mf, proposal->origin->scale,
+		      sizeof (double) * proposal->endsite);
 	      if (proposal->target != proposal->connect)
 		{
 		  t_s_tncon (proposal, obb);
@@ -473,18 +518,25 @@ target_stancoa (proposal_fmt * proposal)
       proposal->v = proposal->time - proposal->origin->tyme;
       proposal->vs = proposal->time - proposal->target->tyme;
       copy_x (proposal, proposal->xf, proposal->origin->x);
-      memcpy(proposal->mf,proposal->origin->scale, sizeof(double)*proposal->endsite);
+      memcpy (proposal->mf, proposal->origin->scale,
+	      sizeof (double) * proposal->endsite);
       copy_x (proposal, proposal->xt, proposal->target->x);
-      memcpy(proposal->mt,proposal->target->scale, sizeof(double)*proposal->endsite);
+      memcpy (proposal->mt, proposal->target->scale,
+	      sizeof (double) * proposal->endsite);
       //CHECK HEREH      memcpy(proposal->mt,proposal->osister->scale, sizeof(double)*proposal->endsite);
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->xt, proposal->mt, proposal->vs);
-      proposal->v = fabs (((proposalack = showtop (crawlback (proposal->target)))->tyme - proposal->time));
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		    proposal->xt, proposal->mt, proposal->vs);
+      proposal->v =
+	fabs (((proposalack =
+		showtop (crawlback (proposal->target)))->tyme -
+	       proposal->time));
       if (proposalack != proposal->oback)
 	{
 	  children (proposalack, &d1, &d2);
 	  if (d1 == proposal->target)
 	    d1 = d2;
-	  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x, d1->scale, d1->v);
+	  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+			d1->x, d1->scale, d1->v);
 	  oldnn = proposalack;
 	  nn = showtop (crawlback (oldnn));
 	  while (nn != proposal->oback)
@@ -492,7 +544,8 @@ target_stancoa (proposal_fmt * proposal)
 	      children (nn, &d1, &d2);
 	      if (d1 == oldnn)
 		d1 = d2;
-	      pseudonuview (proposal, proposal->xf, proposal->mf, oldnn->v, d1->x, d1->scale, d1->v);
+	      pseudonuview (proposal, proposal->xf, proposal->mf, oldnn->v,
+			    d1->x, d1->scale, d1->v);
 	      oldnn = nn;
 	      nn = showtop (crawlback (nn));
 	    }
@@ -508,8 +561,10 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
   proposal->v = proposal->time - proposal->origin->tyme;
   proposal->vs = proposal->time - proposal->target->tyme;
   copy_x (proposal, proposal->xf, proposal->origin->x);
-  memcpy(proposal->mf,proposal->origin->scale, sizeof(double)*proposal->endsite);
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->target->x, proposal->target->scale, proposal->vs);
+  memcpy (proposal->mf, proposal->origin->scale,
+	  sizeof (double) * proposal->endsite);
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		proposal->target->x, proposal->target->scale, proposal->vs);
   nn = showtop (crawlback (proposal->target));
   oldnn = proposal->target;
   proposal->vs = fabs (nn->tyme - proposal->time);
@@ -518,7 +573,8 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
       children (nn, &d1, &d2);
       if (d1 == oldnn)
 	d1 = d2;
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x, d1->scale, d1->v);
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x,
+		    d1->scale, d1->v);
       proposal->vs = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
@@ -526,14 +582,20 @@ t_s_upper (proposal_fmt * proposal, node * connect, node * obb)
   children (nn, &d1, &d2);
   if (d1 == oldnn)
     d1 = d2;
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x, d1->scale, d1->v);
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, d1->x,
+		d1->scale, d1->v);
   proposal->v = obb->tyme - proposal->osister->tyme;
   proposal->vs = obb->tyme - proposal->ocousin->tyme;
   if (connect == proposal->ocousin)
-    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs, proposal->osister->x, proposal->osister->scale, proposal->v);
+    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->vs,
+		  proposal->osister->x, proposal->osister->scale,
+		  proposal->v);
   else
-    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->ocousin->x, proposal->ocousin->scale, proposal->vs);
-  pseudoevaluate (proposal, proposal->xf, proposal->mf, showtop (crawlback (obb)), obb, obb->v);
+    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		  proposal->ocousin->x, proposal->ocousin->scale,
+		  proposal->vs);
+  pseudoevaluate (proposal, proposal->xf, proposal->mf,
+		  showtop (crawlback (obb)), obb, obb->v);
 }
 
 node *
@@ -542,7 +604,8 @@ t_s_obbncon (proposal_fmt * proposal, node * obb)
 
   node *nn, *oldnn, *d1, *d2;
 /*     fprintf(stdout,"t_s_obbncon\n"); */
-  pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
+  pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs,
+		proposal->ocousin->x, proposal->ocousin->scale, proposal->v);
   nn = showtop (crawlback (obb));
   oldnn = obb;
   proposal->vs = fabs (nn->tyme - obb->tyme);
@@ -551,7 +614,8 @@ t_s_obbncon (proposal_fmt * proposal, node * obb)
       children (nn, &d1, &d2);
       if (d1 == oldnn)
 	d1 = d2;
-      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, d1->x, d1->scale, d1->v);
+      pseudonuview (proposal, proposal->xt, proposal->mt, proposal->vs, d1->x,
+		    d1->scale, d1->v);
       proposal->vs = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
@@ -563,7 +627,9 @@ void
 t_s_tncon (proposal_fmt * proposal, node * obb)
 {
   node *nn, *oldnn, *d1, *d2;
-  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->target->x, proposal->target->scale, proposal->time - proposal->target->tyme);
+  pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		proposal->target->x, proposal->target->scale,
+		proposal->time - proposal->target->tyme);
   nn = showtop (crawlback (proposal->target));
   oldnn = proposal->target;
   proposal->v = fabs (nn->tyme - proposal->time);
@@ -572,15 +638,19 @@ t_s_tncon (proposal_fmt * proposal, node * obb)
       children (nn, &d1, &d2);
       if (d1 == oldnn)
 	d1 = d2;
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x, d1->scale, d1->v);
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x,
+		    d1->scale, d1->v);
       proposal->v = nn->v;
       oldnn = nn;
       nn = showtop (crawlback (nn));
     }
   if (obb != proposal->connect)
-    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, proposal->xt, proposal->mt, proposal->vs);
+    pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v,
+		  proposal->xt, proposal->mt, proposal->vs);
   proposal->v = proposal->connect->v;
-  pseudoevaluate (proposal, proposal->xf, proposal->mf, showtop (crawlback (proposal->connect)), proposal->connect, proposal->v);
+  pseudoevaluate (proposal, proposal->xf, proposal->mf,
+		  showtop (crawlback (proposal->connect)), proposal->connect,
+		  proposal->v);
 }
 
 void
@@ -603,8 +673,10 @@ t_s_tcon (proposal_fmt * proposal, node * upper)
       children (obb, &d1, &d2);
       if (d1 == proposal->target)
 	d1 = d2;
-      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x, d1->scale, d1->v);
-      pseudoevaluate (proposal, proposal->xf, proposal->mf, showtop (crawlback (obb)), obb, obb->v);
+      pseudonuview (proposal, proposal->xf, proposal->mf, proposal->v, d1->x,
+		    d1->scale, d1->v);
+      pseudoevaluate (proposal, proposal->xf, proposal->mf,
+		      showtop (crawlback (obb)), obb, obb->v);
     }
 }
 
@@ -652,7 +724,8 @@ connectnodes (node * mother, node * brother, node * sister)
 
   if ((sister != NULL) && (brother != NULL))
     {
-      if ((mother->id == brother->id) || (mother->id == sister->id) || (sister->id == brother->id))
+      if ((mother->id == brother->id) || (mother->id == sister->id)
+	  || (sister->id == brother->id))
 	{
 	  error ("connectnodes() conflict");
 	}
@@ -703,7 +776,9 @@ gotoroot (node * origin, node ** ptrlist)
   node *theNode;
   long i = 0;
 
-  for (theNode = origin; (theNode != NULL) && (crawlback (theNode)->type != 'r'); theNode = showtop (crawlback (theNode)))
+  for (theNode = origin;
+       (theNode != NULL) && (crawlback (theNode)->type != 'r');
+       theNode = showtop (crawlback (theNode)))
     {
       ptrlist[i++] = theNode;
     }
@@ -722,9 +797,11 @@ adjust (node * theNode, double tyme, long level)
       theNode->v = 1;
       theNode->length = DBL_MAX;
       if (theNode->next->back != NULL)
-	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme, level);
+	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
+		level);
       if (theNode->next->next->back != NULL)
-	adjust (crawlback (theNode->next->next), crawlback (theNode->next->next)->tyme, level);
+	adjust (crawlback (theNode->next->next),
+		crawlback (theNode->next->next)->tyme, level);
     }
   else if (theNode->type == 't')
     {
@@ -744,18 +821,21 @@ adjust (node * theNode, double tyme, long level)
 	      theNode->next->tyme = tyme;
 	      theNode->next->v = theNode->v;
 	      theNode->next->length = theNode->length;
-	      adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme, level - 1);
+	      adjust (crawlback (theNode->next),
+		      crawlback (theNode->next)->tyme, level - 1);
 	    }
 	  if (theNode->next->next->back != NULL)
 	    {
 	      theNode->next->next->tyme = tyme;
 	      theNode->next->next->v = theNode->v;
 	      theNode->next->next->length = theNode->length;
-	      adjust (crawlback (theNode->next->next), crawlback (theNode->next->next)->tyme, level - 1);
+	      adjust (crawlback (theNode->next->next),
+		      crawlback (theNode->next->next)->tyme, level - 1);
 	    }
 	}
       else
-	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme, level);
+	adjust (crawlback (theNode->next), crawlback (theNode->next)->tyme,
+		level);
     }
 }
 
@@ -773,7 +853,8 @@ localevaluate (node * mother)
   if (mother->type != 'r')
     {
       set_dirty (mother);
-      for (nn = mother; crawlback (nn)->type != 'r'; nn = showtop (crawlback (nn)))
+      for (nn = mother; crawlback (nn)->type != 'r';
+	   nn = showtop (crawlback (nn)))
 	{
 	  set_dirty (nn);
 	}
@@ -789,7 +870,9 @@ copy_x (proposal_fmt * proposal, xarray_fmt xx1, xarray_fmt xx2)
     case 'a':
     case 'b':
     case 'm':
-      memcpy (xx1.a, xx2.a, sizeof (double) * proposal->world->data->maxalleles[proposal->world->locus]);
+      memcpy (xx1.a, xx2.a,
+	      sizeof (double) *
+	      proposal->world->data->maxalleles[proposal->world->locus]);
       break;
     case 's':
     case 'n':
@@ -828,7 +911,8 @@ fix_root_pop (node * p)
    DOES NOT CHANGE THE TREE
  */
 void
-pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx, node * mother, node * newdaughter, double v)
+pseudoevaluate (proposal_fmt * proposal, xarray_fmt x, double *lx,
+		node * mother, node * newdaughter, double v)
 {
   node *nn = NULL, *d1 = NULL, *d2 = NULL, *oldnn = NULL;
 
