@@ -16,6 +16,7 @@ $Id: migrate_mpi.c,v 1.11 2001/09/07 23:56:13 beerli Exp $
 #include "options.h"
 #include "world.h"
 #include "joint-chains.h"
+#include "data.h"
 /*should go into profile.h*/
 #define GRIDSIZE 9
 
@@ -25,6 +26,9 @@ extern void run_locus (world_fmt ** universe, int usize,
 		       long locus, long *treefilepos, long *Gmax);
 
 long pack_databuffer (char **buffer, data_fmt * data, option_fmt * options);
+void unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options);
+void pack_allele_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind);
+void pack_sequence_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind);
 void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 void mpi_results_master (double sendtype, world_fmt * world,
 			 long maxrep,
@@ -412,12 +416,13 @@ void
 broadcast_options_worker (option_fmt * options)
 {
   long bufsize;
-  char *buffer;
+  char *buffer, *sbuffer;
   MPI_Bcast (&bufsize,1, MPI_LONG, MASTER, comm_world);
-  buffer = (char *) calloc (bufsize, sizeof (char));    
+  buffer = (char *) calloc (bufsize+1, sizeof (char));    
+  sbuffer = buffer;
   MPI_Bcast (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
   read_options_worker (&buffer, options);
-  free (buffer);
+  free (sbuffer);
 }
 
 
@@ -441,34 +446,262 @@ broadcast_data_worker (data_fmt * data, option_fmt * options)
   MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
   buffer = (char *) calloc (bufsize, sizeof (char));
   MPI_Bcast (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
+  unpack_databuffer(buffer, data, options);
   free (buffer);
 }
 
 long
 pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
 {
-  long locus;
+  long locus, pop, ind;
   long bufsize = 0;
+#ifdef UEP
+  long sumtips, i;
+#endif
   char fp[LINESIZE];
   bufsize += LINESIZE;
   *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-  sprintf (fp, "%c%li%li%c%s\n", options->datatype, data->numpop,
-	   data->loci, data->dlm, options->title);
-  strcat(*buffer, fp);
+  sprintf (fp, "%c %li %li %li\n", options->datatype, (long) data->hasghost, data->numpop,
+	   data->loci);
+   bufsize += strlen (fp)+1;
+   *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);	   
+   strcat(*buffer, fp);
   for (locus = 0; locus < data->loci; locus++)
     {
-      sprintf (fp, "%li ", data->seq->sites[locus]);
+      sprintf (fp, "%li\n", data->seq->sites[locus]);
       bufsize += strlen (fp)+1;
      *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
       strcat(*buffer, fp);
     }
-  sprintf (fp, "\n%li %f", data->seq->addon, data->seq->fracchange);
+  sprintf (fp, "%li %f\n", data->seq->addon, data->seq->fracchange);
         bufsize += strlen (fp)+1;
      *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
       strcat(*buffer, fp);
+// population data
+  for (pop = 0; pop < data->numpop; pop++)
+    {
+	sprintf (fp, "%li %s\n", data->numind[pop][FLOC], data->popnames[pop]);
+        bufsize += strlen (fp)+1;
+       *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+       strcat(*buffer, fp);
+	for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+	{
+		sprintf (fp, "%*.*s\n", (int) options->nmlength, (int) options->nmlength,data->indnames[pop][ind]);
+		bufsize += strlen (fp)+1;
+		*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+		strcat(*buffer, fp);
+		if (strchr (SEQUENCETYPES, options->datatype))
+			pack_sequence_data(buffer, &bufsize, data, pop, ind);
+		else	
+			pack_allele_data(buffer,&bufsize, data, pop, ind);
+	}
+    }
+// geofile	
+  if (options->geo)
+  {
+	for(pop=0; data->numpop * data->numpop ; pop++)
+	{
+		sprintf (fp, "%f %f\n", data->geo[pop], data->lgeo[pop]);
+		bufsize += strlen (fp)+1;
+		*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+		strcat(*buffer, fp);
+	}
+  }
+  // uepfile
+#ifdef UEP  
+  if (options->uep)
+  {
+	sumtips =0;
+	for (pop = 0; pop < data->numpop; ++pop)
+		sumtips += data->numind[pop][FLOC];
+	sprintf (fp, "%li %li\n",sumtips, data->uepsites);
+	bufsize += strlen (fp)+1;
+	*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+	strcat(*buffer, fp);
+          if (strchr (SEQUENCETYPES, options->datatype))
+	{
+		for(pop=0; sumtips; pop++)
+		{
+			for(i=0; i<data->uepsites; i++)
+			{
+				sprintf (fp, "%li\n",data->uep[pop][i]);
+				bufsize += strlen (fp)+1;
+				*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+				strcat(*buffer, fp);
+			}
+		}
+	}
+	else
+	{
+		for(pop=0; sumtips; pop++)
+		{
+			for(i=0; i<data->uepsites; i++)
+			{
+				sprintf (fp, "%li %li\n",data->uep[pop][i], data->uep[pop+sumtips][i]);
+				bufsize += strlen (fp)+1;
+				*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
+				strcat(*buffer, fp);
+			}
+		}
+	}		
+  }
+
+#endif
   return bufsize;
 }
 
+void pack_allele_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind)
+{
+	char fp[LINESIZE];
+	long locus;
+	for (locus = 0; locus < data->loci; locus++)
+	{
+		sprintf (fp, "%s %s\n",data->yy[pop][ind][locus][0],data->yy[pop][ind][locus][1]);
+		*bufsize += strlen (fp)+1;
+		*buffer = (char *) realloc(*buffer, sizeof(char) * *bufsize);
+		strcat(*buffer, fp);
+	}
+}
+
+void pack_sequence_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind)
+{
+	char *fp;
+	long locus;
+	fp = calloc(1,sizeof(char));
+	for (locus = 0; locus < data->loci; locus++)
+	{
+		fp = (char *) realloc(fp, data->seq->sites[locus] * sizeof(char));
+		sprintf (fp, "%s\n", data->yy[pop][ind][locus][0]);
+		*bufsize += strlen (fp)+1;
+		*buffer = (char *) realloc(*buffer, sizeof(char) * *bufsize);
+		strcat(*buffer, fp);
+	}
+	free(fp);
+}
+
+// this function and get_data() do not mix well!
+void
+unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
+{
+  long locus, pop, ind, i;
+#ifdef UEP
+  long sumtips;
+#endif
+  char *buf = buffer;
+  char *input;
+  long hasghost;
+  input = (char *) calloc(LINESIZE,sizeof(char));
+  sgets(input, LINESIZE, &buf);
+  sscanf (input, "%c%li%li%li", &options->datatype, &hasghost, &data->numpop,
+	   &data->loci);
+  data->hasghost = (boolean) hasghost;
+  init_data_structure1 (&data, options);
+  for (locus = 0; locus < data->loci; locus++)
+    {
+        sgets(input, LINESIZE, &buf);
+	sscanf (input,  "%li", &data->seq->sites[locus]);
+    }
+    sgets(input, LINESIZE, &buf);
+     sscanf (input, "%li%lf", &data->seq->addon, &data->seq->fracchange);
+// population data
+  for (pop = 0; pop < data->numpop; pop++)
+    {
+	sgets(input, LINESIZE, &buf);
+	sscanf (input,  "%li%s", &data->numind[pop][FLOC], data->popnames[pop]);
+	init_data_structure2 (&data, options, pop);
+	for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+	{
+		sgets(input, LINESIZE, &buf);
+		sscanf (input, "%s", data->indnames[pop][ind]);
+		if (strchr (SEQUENCETYPES, options->datatype))
+		{
+			for (locus = 0; locus < data->loci; locus++)
+			{
+				input = (char *) realloc(input,sizeof(char) *(100+ data->seq->sites[locus]));
+				sgets(input, 100+ data->seq->sites[locus], &buf);
+				sscanf (input, "%s", data->yy[pop][ind][locus][0]);
+			}
+		}
+		else	
+		{
+			for (locus = 0; locus < data->loci; locus++)
+			{
+				sgets(input, LINESIZE, &buf);
+				sscanf (input,  "%s %s", data->yy[pop][ind][locus][0], data->yy[pop][ind][locus][1]);
+			}
+		}
+	}
+    }
+// geofile
+  data->geo = (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
+  data->lgeo = (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
+  if (!options->geo)
+    {
+      for (i = 0; i < data->numpop * data->numpop; i++)
+	data->geo[i] = 1.0;
+    }
+    else  
+    {
+	for(pop=0; data->numpop * data->numpop ; pop++)
+	{
+		sgets(input, LINESIZE, &buf);
+		sscanf (input,  "%lf%lf", &data->geo[pop], &data->lgeo[pop]);
+	}
+  }
+  // uepfile
+#ifdef UEP  
+  if (options->uep)
+  {
+	sgets(input, LINESIZE, &buf);
+	sscanf (input,  "%li%li",&sumtips, &data->uepsites);
+	data->uep = (long **) calloc (number_genomes (options->datatype) * sumtips,
+				sizeof (long *));
+	if (strchr (SEQUENCETYPES, options->datatype))
+	{		
+		for(pop=0; sumtips; pop++)
+		{
+			data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
+			for(i=0; i<data->uepsites; i++)
+			{
+				sgets(input, LINESIZE, &buf);
+				sscanf (input,  "%li",&data->uep[pop][i]);
+			}
+		}
+	}
+	else
+	{		
+		for(pop=0; sumtips; pop++)
+		{
+			data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
+			data->uep[i+sumtips] = (long *) calloc (data->uepsites, sizeof (long));
+			for(i=0; i<data->uepsites; i++)
+			{
+				sgets(input, LINESIZE, &buf);
+				sscanf (input,  "%li%li",&data->uep[pop][i], &data->uep[pop+sumtips][i]);
+			}
+		}
+	}
+		
+  }
+#endif
+  init_data_structure3 (data);
+  /* replace this, if loci can have different number of ind */
+  set_numind (data);
+  switch (options->datatype)
+    {
+    case 'a':
+      create_alleles (data);
+      break;
+    case 'b':
+    case 'm':
+      create_alleles (data);
+      for (pop = 0; pop < data->loci; pop++)
+	data->maxalleles[pop] = options->micro_stepnum;
+      break;
+    }
+	free(input);
+}
+
 void
 unpack_result_buffer (char *buffer, world_fmt * world,
 		      long locus, long maxrep, long numpop)
@@ -550,14 +783,14 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
   char *buf = buffer;
   aa = &world->mighistloci[locus];
   sgets (input, LINESIZE, &buf);
-  sscanf (input, "%li\n", &aa->mighistnum);
+  sscanf (input, "%li", &aa->mighistnum);
   aa->mighist = (mighist_fmt *) realloc (aa->mighist,
 					 sizeof (mighist_fmt) *
 					 aa->mighistnum);
   for (j = 0; j < aa->mighistnum; j++)
     {
       sgets (input, LINESIZE, &buf);
-      sscanf (input, "%li %li %li\n", &aa->mighist[j].copies,
+      sscanf (input, "%li %li %li", &aa->mighist[j].copies,
 	      &aa->mighist[j].weight, &aa->mighist[j].migeventsize);
       aa->mighist[j].migevents =
 	(migevent_fmt *) realloc (aa->mighist[j].migevents,
@@ -566,7 +799,7 @@ unpack_mighist_buffer (char *buffer, world_fmt * world,
       for (i = 0; i < aa->mighist[j].migeventsize; i++)
 	{
 	  sgets (input, LINESIZE, &buf);
-	  sscanf (input, "%lf %lf %lf\n",
+	  sscanf (input, "%lf %lf %lf",
 		  &aa->mighist[j].migevents[i][0],
 		  &aa->mighist[j].migevents[i][1],
 		  &aa->mighist[j].migevents[i][2]);
@@ -622,7 +855,7 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
   for (r = 0; r < maxrep; r++)
     {
       sgets (input, LINESIZE, &buf);
-      sscanf (input, "%li %li %li %lf\n", &ta[r][l].T, &ta[r][l].numpop,
+      sscanf (input, "%li %li %li %lf", &ta[r][l].T, &ta[r][l].numpop,
 	      &ta[r][l].sumtips, &ta[r][locus].param_like);
       increase_timearchive (world, l, ta[r][l].T, world->numpop, r);
       for (i = 0; i < ta[r][l].T; i++)
@@ -633,18 +866,18 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
 	  for (j = 0; j < 3*numpop + numpop * (numpop-1); j++)
 	  {
 	      sgets (input, LINESIZE, &buf);
-	      sscanf (input, "%lf\n", &ta[r][l].tl[i].data[j]);
+	      sscanf (input, "%lf", &ta[r][l].tl[i].data[j]);
 	    }
 	}
       for (i = 0; i < world->numpop2; i++)
 	{
 	  sgets (input, LINESIZE, &buf);
-	  sscanf (input, "%lg %lg\n", &ta[r][l].param[i],
+	  sscanf (input, "%lg %lg", &ta[r][l].param[i],
 		  &ta[r][l].param0[i]);
 	}
       log_param0 (ta[r][l].param0, ta[r][l].lparam0, world->numpop2);
       sgets (input, LINESIZE, &buf);
-      sscanf (input, "%li %lg\n", &ta[r][l].trials, &ta[r][l].normd);
+      sscanf (input, "%li %lg", &ta[r][l].trials, &ta[r][l].normd);
     }
 }
 
@@ -813,7 +1046,7 @@ mpi_profiles_master (world_fmt *world, long nparam, int *profilewho)
 {
   long pnum;
   int sender;
-  int i;
+//  int i;
   long pdone;
   MPI_Status status;
   long temp[3];
