@@ -47,8 +47,8 @@ extern double mpi_likelihood_master (double *param, double *lparam,
 extern void broadcast_options_master (option_fmt * options);
 extern void broadcast_options_worker (option_fmt * options);
 
-//extern void broadcast_data_master(data_fmt *data, option_fmt *options);
-//extern void broadcast_data_worker(data_fmt *data, option_fmt *options);
+extern void broadcast_data_master(data_fmt *data, option_fmt *options);
+extern void broadcast_data_worker(data_fmt *data, option_fmt *options);
 extern void mpi_results_master (double sendtype, world_fmt * world,
 				long maxrep,
 				void (*unpack) (char *buffer,
