@@ -10,7 +10,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: profile.c,v 1.54 2001/07/25 19:27:24 beerli Exp $
+$Id: profile.c,v 1.55 2001/09/07 23:56:13 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -41,10 +41,10 @@ void calc_profile_likelihood (char method, long which, double *likes,
 void print_profile_likelihood (long which, world_fmt * world, long *gmaxptr);
 void prepare_header (char *var, long which, world_fmt * world);
 void print_profile_title (world_fmt * world);
-void print_profile_table (char method, long which, char *var, double *likes,
+void print_profile_table (char method, long which, char *var, double likes[],
 			  double **param, world_fmt * world);
 void print_profile_percentile (world_fmt * world);
-void print_percentile_header (FILE * outfile, boolean first);
+void sprint_percentile_header (char * outfile, boolean first);
 void allocate_profile_percentiles (world_fmt * world);
 void destroy_profile_percentiles (world_fmt * world);
 void print_menu_profile (long which, long nn);
@@ -92,8 +92,8 @@ long set_profile_param (double *param, long which, long *allwhich,
 			double xval, double *xvals, world_fmt * world);
 void addinvar (double *param, long *fixed, long *allwhich, double *xvals,
 	       long start, long len);
-void print_nice_param (double parameter, double bottom, double top,
-		       FILE * file);
+void sprint_nice_param (double parameter, double bottom, double top,
+		       char * file);
 
 
 
@@ -113,7 +113,7 @@ print_profile_likelihood_driver (long which, world_fmt * world, long *gmaxptr)
   static boolean onetheta = FALSE;
   static boolean onemig = FALSE;
   long i, j;
-  world->options->verbose = FALSE;
+  //world->options->verbose = FALSE;
 
   if (which == world->numpop2)	//gamma deviated mutation rate
     print_profile_likelihood (which, world, gmaxptr);
@@ -189,7 +189,7 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
   prepare_header (var, which, world);
   if (world->options->printprofile)
     {
-      print_profile_table (method, which, var, likes, param, world);
+	print_profile_table (method, which, var, likes, param, world);
     }
   if (world->options->printprofsummary)
     {
@@ -206,7 +206,7 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
 }
 
 void
-print_profile_table (char method, long which, char *var, double *likes,
+print_profile_table (char method, long which, char *var, double likes[],
 		     double **param, world_fmt * world)
 {
   const double probabilities[] = SHOWGRID;
@@ -216,11 +216,13 @@ print_profile_table (char method, long which, char *var, double *likes,
   long elem =
     world->options->gamma ? world->numpop * world->numpop +
     1 : world->numpop * world->numpop;
-
-  FILE *outfile = world->outfile;
+	
+//  FILE *outfile = world->outfile;
+  char fp[LINESIZE * 10]; //large local string buffer
+  char *buffer = world->buffer; // buffer for printing whole table
   char *temp, *var2, temp2[LINESIZE], likestr[LINESIZE], *paramstr;
   double likemax = -DBL_MAX;
-
+  memset(buffer,0,sizeof(char)*strlen(buffer));
   var2 =
     (char *) calloc (1,
 		     sizeof (char) * MAX (LINESIZE,
@@ -270,14 +272,19 @@ print_profile_table (char method, long which, char *var, double *likes,
 	      "Parameters are evaluated assuming complete independence\n and then once maximized at the found profiled parameter value");
       break;
     }
-  fprintf (outfile, "\n\nProfile likelihood for parameter %s\n", var);
-  fprintf (outfile, "%s\n", methodstring);
-  print_line (outfile, '-', 79, CONT);
+  sprintf (fp, "\n\nProfile likelihood for parameter %s\n", var);
+  strcat(buffer,fp);
+  sprintf (fp, "%s\n", methodstring);
+  strcat(buffer,fp);
+  sprint_line (fp, '-', 79, CONT);
+  strcat(buffer,fp);
   if (method == 'd')
-    fprintf (outfile, "      Ln(L)     %7.7s     %s\n", var, var2);
+    sprintf (fp, "      Ln(L)     %7.7s     %s\n", var, var2);
   else
-    fprintf (outfile, "Per.  Ln(L)     %7.7s     %s\n", var, var2);
-  print_line (outfile, '-', 79, START);
+    sprintf (fp, "Per.  Ln(L)     %7.7s     %s\n", var, var2);
+    strcat(buffer,fp);
+  sprint_line (fp, '-', 79, START);
+    strcat(buffer,fp);
   for (i = 0; i < GRIDSIZE; i++)
     {
       if (likemax < MIN (likes[i], DBL_MAX))
@@ -316,35 +323,35 @@ print_profile_table (char method, long which, char *var, double *likes,
       if (param[i][which] <= 0)
 	{
 	  if (method == 'd')
-	    fprintf (outfile, "        -           -       %s\n", paramstr);
+	    sprintf (fp, "        -           -       %s\n", paramstr);
 	  else
-	    fprintf (outfile, "%3.3f     -           -       %s\n",
+	    sprintf (fp, "%3.3f     -           -       %s\n",
 		     probabilities[i], paramstr);
+	  strcat(buffer,fp);
 	}
       else
 	{
 	  if (method == 'd')
-	    fprintf (outfile, "    %8.8s % 10.6g %s\n", likestr,
+	    sprintf (fp, "    %8.8s % 10.6g %s\n", likestr,
 		     param[i][which], paramstr);
 	  else
 	    {
 	      if (probabilities[i] == 0.5)
-		fprintf (outfile, "MLE   %8.8s % 10.6g %s\n",
+		sprintf (fp, "MLE   %8.8s % 10.6g %s\n",
 			 likestr, param[i][which], paramstr);
 	      else
-		fprintf (outfile, "%4.3f %8.8s % 10.6g %s\n",
+		sprintf (fp, "%4.3f %8.8s % 10.6g %s\n",
 			 probabilities[i], likestr,
 			 param[i][which], paramstr);
 	    }
+	  strcat(buffer,fp);
 	}
     }
-  print_line (outfile, '-', 79, STOP);
-  fprintf (outfile,
-	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
-  fprintf (outfile,
-	   "    in the parameter direction, the likelihood surface is so flat\n");
-  fprintf (outfile,
-	   "    that the calculation of the percentile(s)  failed.\n");
+  sprint_line (fp, '-', 79, STOP);
+    strcat(buffer,fp);
+  sprintf (fp,
+	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n   in the parameter direction, the likelihood surface is so flat\n    that the calculation of the percentile(s)  failed.\n");
+	     strcat(buffer,fp);
   free (paramstr);
   free (var2);
 }
@@ -386,85 +393,105 @@ print_profile_percentile (world_fmt * world)
   long i, j, jj;
   boolean first = TRUE;
   boolean last = FALSE;
-  fprintf (world->outfile, "\n\n");
-  print_line (world->outfile, '=', 79, CONT);
-  fprintf (world->outfile,
+  char fp[LINESIZE];
+  memset(world->buffer,0,sizeof(char)*strlen(world->buffer));
+  sprintf (fp, "\n\n");
+  strcat(world->buffer,fp);
+  sprint_line (fp, '=', 79, CONT);
+  strcat(world->buffer,fp);
+  sprintf (fp,
 	   "Summary of profile likelihood percentiles of all parameters\n");
-  print_line (world->outfile, '=', 79, CONT);
-  fprintf (world->outfile, "\n");
-  print_percentile_header (world->outfile, first);
+  strcat(world->buffer,fp);	   
+  sprint_line (fp, '=', 79, CONT);
+  strcat(world->buffer,fp);
+  sprintf(fp, "\n");
+  strcat(world->buffer,fp);
+  sprint_percentile_header (fp, first);
+  strcat(world->buffer,fp);
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
 	continue;		/* this variable was not estimated, so return */
-      fprintf (world->outfile, "%-10.10s  ", world->quantiles[i].name);
+      sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
+      strcat(world->buffer,fp);
       for (jj = 0; jj < GRIDSIZE; jj++)
 	{
 	  j = warp (jj);
 	  if (probabilities[j] > 0.5)
 	    continue;
 	  if (world->quantiles[i].param[j] < 0)
-	    fprintf (world->outfile, "      -       ");
+	    sprintf (fp, "      -       ");
 	  else
-	    print_nice_param (world->quantiles[i].param[j], 0.000001,
-			      999.99999, world->outfile);
+	    sprint_nice_param (world->quantiles[i].param[j], 0.000001,
+			      999.99999, fp);
+	    strcat(world->buffer,fp);
 	}
-      fprintf (world->outfile, "\n");
+      sprintf (fp, "\n");
+      strcat(world->buffer,fp);
     }
-  fprintf (world->outfile, "\n\n");
-  print_percentile_header (world->outfile, last);
+  sprintf (fp, "\n\n");
+  strcat(world->buffer,fp);
+  sprint_percentile_header (fp, last);
+  strcat(world->buffer,fp);
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
 	continue;		/* this variable was not estimated, so return */
-      fprintf (world->outfile, "%-10.10s  ", world->quantiles[i].name);
+      sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
+      strcat(world->buffer,fp);
       for (jj = 0; jj < GRIDSIZE; jj++)
 	{
 	  j = warp (jj);
 	  if (probabilities[j] < 0.5)
 	    continue;
 	  if (world->quantiles[i].param[j] < 0)
-	    fprintf (world->outfile, "      -       ");
+	    sprintf (fp, "      -       ");
 	  else
-	    print_nice_param (world->quantiles[i].param[j], 0.000001,
-			      999.99999, world->outfile);
+	    sprint_nice_param (world->quantiles[i].param[j], 0.000001,
+			      999.99999, fp);
+	   strcat(world->buffer,fp);
 	}
-      fprintf (world->outfile, "\n");
+      sprintf (fp, "\n");
+      strcat(world->buffer,fp);
     }
 
-  fprintf (world->outfile, "\n");
-  print_line (world->outfile, '-', 80, CONT);
-  fprintf (world->outfile,
-	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n");
-  fprintf (world->outfile,
-	   "    in the parameter direction, the likelihood surface is so flat\n");
-  fprintf (world->outfile,
-	   "    that the percentiles cannot be calculated.\n");
+  sprintf (fp, "\n");
+  strcat(world->buffer,fp);
+  sprint_line (fp, '-', 80, CONT);
+  strcat(world->buffer,fp);
+  sprintf (fp,
+	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n    in the parameter direction, the likelihood surface is so flat\n    that the percentiles cannot be calculated.\n");
+    strcat(world->buffer,fp);
 }
 
 void
-print_nice_param (double parameter, double bottom, double top, FILE * file)
+sprint_nice_param (double parameter, double bottom, double top, char * file)
 {
   if (parameter > 0.000001 && parameter < 999.99999)
-    fprintf (file, " %11.6f  ", parameter);
+    sprintf (file, " %11.6f  ", parameter);
   else
-    fprintf (file, " %11.6g ", parameter);
+    sprintf (file, " %11.6g ", parameter);
 }
 
 void
-print_percentile_header (FILE * outfile, boolean first)
+sprint_percentile_header (char * outfile, boolean first)
 {
   const double probabilities[] = GRID2;
   long i;
+  char fp[LINESIZE];
   if (first)
-    fprintf (outfile,
+    sprintf (fp,
 	     "Parameter                          Lower percentiles\n");
   else
-    fprintf (outfile,
+    sprintf (fp,
 	     "Parameter                          Upper percentiles\n");
-  fprintf (outfile, "            ");
-  print_line (outfile, '-', 68, CONT);
-  fprintf (outfile, "            ");
+  strcat(outfile,fp);		 
+  sprintf (fp, "            ");
+  strcat(outfile,fp);
+  sprint_line (fp, '-', 68, CONT);
+  strcat(outfile,fp);
+  sprintf (fp, "            ");
+  strcat(outfile,fp);
   for (i = 0; i < GRIDSIZE - 1; i++)
     {
       if (first)
@@ -478,15 +505,18 @@ print_percentile_header (FILE * outfile, boolean first)
 	    continue;
 	}
       if (probabilities[i] == 0.5)
-	fprintf (outfile, "    MLE       ");
+	sprintf (fp, "    MLE       ");
       else
-	fprintf (outfile, "    %5.3f     ", probabilities[i]);
+	sprintf (fp, "    %5.3f     ", probabilities[i]);
+      strcat(outfile,fp);
     }
   if (probabilities[i] == 0.5)
-    fprintf (outfile, "    MLE\n");
+    sprintf (fp, "    MLE\n");
   else
-    fprintf (outfile, "    %5.3f\n", probabilities[i]);
-  print_line (outfile, '-', 80, CONT);
+    sprintf (fp, "    %5.3f\n", probabilities[i]);
+  strcat(outfile,fp);
+  sprint_line (fp, '-', 80, CONT);
+  strcat(outfile,fp);
 }
 
 
@@ -545,8 +575,8 @@ calc_profile_likelihood (char method, long which, double *likes,
 	    }
 	}
     }
-  else
-    printf ("           Using M (m/mu) instead of 4Nm\n");
+  //else
+  //  printf ("           Using M (m/mu) instead of 4Nm\n");
 }
 
 
@@ -659,8 +689,8 @@ profile_max_percentiles (long which, double *likes, double **param,
       memcpy (param[i], mlparam,
 	      sizeof (double) * (world->numpop2 +
 				 (long) world->options->gamma));
-      trials =
-	find_profilelike (testlike, i, minparam, maxparam, param[i],
+      trials =/* prob was testlike*/
+	find_profilelike (prob, i, minparam, maxparam, param[i],
 			  &likes[i], which, world, QD, QD2, mlparam, &normd,
 			  nr);
       if (world->options->progress)
@@ -1141,7 +1171,12 @@ find_profilelike (double testlike, long whichprob, double minparam,
   const double probabilities[] = GRID;
 #ifndef MPI
   long locus, r;
+#else
+#ifdef SLOWNET
+//long locus, r;
 #endif
+#endif
+
   //  boolean test;
   double tmp;
   //  double likes=0;
@@ -1177,8 +1212,7 @@ find_profilelike (double testlike, long whichprob, double minparam,
     }
   if (QD)
     {
-
-#ifndef MPI
+/*#ifndef MPI
       for (locus = 0; locus < world->loci; locus++)
 	{
 	  if (world->repkind == SINGLECHAIN)
@@ -1190,12 +1224,33 @@ find_profilelike (double testlike, long whichprob, double minparam,
 	    }
 	  else
 	    {
-	      // interpolate_like(nr, locus);
+	     //interpolate_like(nr, locus);
 	      for (r = nr->repstart; r < nr->repstop; r++)
 		create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
 	    }
 	}
+#else
+#ifdef SLOWNET
+      for (locus = 0; locus < world->loci; locus++)
+	{
+	  if (world->repkind == SINGLECHAIN)
+	    {
+	      for (r = 0; r < world->repstop; r++)
+		{
+		  create_apg0 (nr->apg0[r][locus], nr, &world->atl[r][locus]);
+		}
+	    }
+	  else
+	    {
+		exit(-1);
+	     // interpolate_like(nr, locus);
+	      //for (r = nr->repstart; r < nr->repstop; r++)
+		//create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
+	    }
+	}
 #endif
+#endif 
+*/
       memcpy (testparam, mlparam, sizeof (double) *
 	      (world->numpop2 + (long) world->options->gamma));
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
@@ -1203,7 +1258,7 @@ find_profilelike (double testlike, long whichprob, double minparam,
       testparam[which] = xlow;
       set_logparam (ltestparam, testparam, nr->partsize);
       fill_helper (&helper, testparam, ltestparam, nr->world, nr);
-      low = calc_loci_like (&helper, testparam, ltestparam);
+      low = CALCLIKE (&helper, testparam, ltestparam);
       memcpy (testparam, mlparam, sizeof (double) *
 	      (world->numpop2 + (long) world->options->gamma));
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
@@ -1211,7 +1266,7 @@ find_profilelike (double testlike, long whichprob, double minparam,
       testparam[which] = xhigh;
       set_logparam (ltestparam, testparam, nr->partsize);
       fill_helper (&helper, testparam, ltestparam, world, nr);
-      high = calc_loci_like (&helper, testparam, ltestparam);
+      high = CALCLIKE (&helper, testparam, ltestparam);
     }
   else
     {
@@ -1225,6 +1280,10 @@ find_profilelike (double testlike, long whichprob, double minparam,
 					  xhigh, nr->values, world);
       maximize (testparam, world, nr, PROFILE, world->repkind);
       high = nr->llike;
+	  	      testlike = high - 0.5 * find_chi (1, testlike);
+      
+	  if(high< world->atl[0][world->loci].param_like)
+		printf("%i> DARN: high=%f ml=%f xigh=%f mlparam[which]=%f testlike=%f\n", myID, high, world->atl[0][world->loci].param_like,xhigh,mlparam[which],testlike); 
     }
   panic = 0;
   x = (xhigh + xlow) / 2.;
@@ -1239,7 +1298,7 @@ find_profilelike (double testlike, long whichprob, double minparam,
 	  testparam[which] = x;
 	  set_logparam (ltestparam, testparam, nr->partsize);
 	  fill_helper (&helper, testparam, ltestparam, world, nr);
-	  mid = calc_loci_like (&helper, testparam, ltestparam);
+	  mid = CALCLIKE (&helper, testparam, ltestparam);
 	}
       else
 	{
@@ -1395,17 +1454,3 @@ set_df (long which, char *custm2, long numpop, long numpop2)
     }
   return -1;
 }
-
-/*
-void
-bootstrap(world_fmt *world, double *param)
-{
-    long g;
-    
-    for(g=0;g<world->options->bootg;g++)
-    {
-        create_genealogy_time(world);
-    }
-}
-
-*/
