@@ -92,7 +92,7 @@ getseed (option_fmt * options)
     }
 #ifndef SPRNG
 #ifdef MPI
-  MPI_Bcast (&options->inseed, 1, MPI_LONG, MASTER, MPI_COMM_WORLD);
+  MPI_Bcast (&options->inseed, 1, MPI_LONG, MASTER, comm_world);
   if (myID != MASTER)
     {
       for (i = 1; i <= 1000; i++)	/* clear the random number generator */
