@@ -13,7 +13,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: tools.h,v 1.16 2001/06/02 21:40:21 beerli Exp $
+$Id: tools.h,v 1.17 2001/07/25 19:27:24 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -23,41 +23,49 @@ extern node *crawlback (const node * theNode);
 extern node *crawl (node * theNode);
 extern node *showtop (node * theNode);
 extern void adjust_time (node * theNode, double tyme);
-extern void insert_migr_node (world_fmt * world, node * up, node * down, migr_table_fmt * migr_table, long *migr_table_counter);
+extern void insert_migr_node (world_fmt * world, node * up, node * down,
+			      migr_table_fmt * migr_table,
+			      long *migr_table_counter);
 extern void children (node * mother, node ** brother, node ** sister);
 /* math tools */
 extern double incompletegamma (double x, double alpha);
 extern double polygamma (long n, double z);
 extern void invert_matrix (double **a, long nsize);
-extern boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton);
+extern boolean nrcheck (double **m, double **tm, double *v, long nrows,
+			double *r1, double *r2, boolean do_newton);
 extern double rannor (double mean, double sd);
 extern double find_chi (long df, double prob);
-extern double probchiboundary(double chi, long zeros, long all);
+extern double probchiboundary (double chi, long zeros, long all);
 extern double chiboundary (long zeros, long nonzeros, double alpha);
 extern double probchi (long df, double chi);
 extern double chisquare (long df, double alpha);
-extern void gamma_rates (double *rate, double *probcat, long categs, char *input);
+extern void gamma_rates (double *rate, double *probcat, long categs,
+			 char *input);
 #ifndef HAVE_LGAMMA
 extern double mylgamma (double z);
 #endif
 extern double sum (double *vector, long n);
-extern double logfac(long n);
+extern double logfac (long n);
 
 extern char lowercase (char c);
 extern char uppercase (char c);
 
 /* vector initialization and calc*/
-extern void doublevec1d(double **v, long size);
-extern void doublevec2d(double ***v, long size1, long size2);
-extern void free_doublevec2d(double **v);
-extern void setdoublevec1d(double **v, double *w, long size);
-extern void add_vector(double *result, double *v, long size);
+extern void doublevec1d (double **v, long size);
+extern void doublevec2d (double ***v, long size1, long size2);
+extern void free_doublevec2d (double **v);
+extern void setdoublevec1d (double **v, double *w, long size);
+extern void add_vector (double *result, double *v, long size);
 
 /*filemanipulation */
-extern void init_files (world_fmt * world, data_fmt * data, option_fmt * options);
-extern void exit_files (world_fmt * world, data_fmt * data, option_fmt * options);
-extern void openfile (FILE ** fp, char *filename, char *mode, const char *application, char *perm);
-extern long read_savesum (world_fmt * world, option_fmt * options, data_fmt * data);
+extern void init_files (world_fmt * world, data_fmt * data,
+			option_fmt * options);
+extern void exit_files (world_fmt * world, data_fmt * data,
+			option_fmt * options);
+extern void openfile (FILE ** fp, char *filename, char *mode,
+		      const char *application, char *perm);
+extern long read_savesum (world_fmt * world, option_fmt * options,
+			  data_fmt * data);
 extern void write_savesum (world_fmt * world);
 
 /* string manipulation */
@@ -80,10 +88,9 @@ extern long mmstart (long pop, long numpop);
 extern long mmend (long pop, long numpop);
 extern long mml2m (long pos, long numpop);
 extern void print_line (FILE * outfile, char c, long nn, long flag);
+extern void sprint_line (char *buffer, char c, long nn, long flag);
 /* reading from char * buffer */
-char sgetc(char **buffer);
-char *sgets(char *s, int size, char **stream);
+char sgetc (char **buffer);
+char *sgets (char *s, int size, char **stream);
 
 #endif /*TOOLS_INCLUDE */
-
-
